<template>
    <div class="home-container">
        <div style="height: 100%">
            <el-row class="homeCard">
                <div class="basic-line">
                    <span>设备编码：</span>
                    <el-input v-model="equipmentState.searchQuery.deviceCode" clearable filterable class="input-box" placeholder="设备编码">
                    </el-input>
                </div>
                <div class="basic-line">
                    <span>设备名称：</span>
                    <el-input v-model="equipmentState.searchQuery.deviceName" clearable filterable class="input-box" placeholder="设备名称">
                    </el-input>
                </div>
                <div class="basic-line">
                    <span>设备功率：</span>
                    <el-input v-model="equipmentState.searchQuery.devicePower" clearable filterable class="input-box" placeholder="设备功率">
                    </el-input>
                </div>
                <div class="basic-line">
                    <span>是否特种设备：</span>
                    <el-select v-model="equipmentState.searchQuery.specialDevice" clearable filterable class="input-box" placeholder="是否特种设备">
                        <el-option v-for="item in equipmentState.specialDeviceList" :key="item.id" :label="item.name" :value="item.id"></el-option>
                    </el-select>
                </div>
                <div style="padding-bottom: 10px">
                    <el-button type="primary" @click="getEquipmentData">查询</el-button>
                    <el-button plain @click="reset">重置</el-button>
                </div>
            </el-row>
            <div class="homeCard">
                <div class="main-card">
                    <el-row class="cardTop">
                        <el-col :span="12" class="mainCardBtn">
                            <el-button type="primary" :icon="Plus" size="default" @click="openEquipmentDialog('新增', {})">新增</el-button>
                            <!--                            <el-button type="danger" :icon="Delete" size="default" plain>删除</el-button>-->
                        </el-col>
<!--                        <el-button type="primary" :icon="Refresh" size="default" />-->
                    </el-row>
                    <el-table ref="multipleTableRef" :data="equipmentState.equipmentData" style="width: 100%" height="calc(100% - 100px)" :header-cell-style="{ background: '#fafafa' }">
                        <el-table-column prop="deviceCode" label="设备编号"/>
                        <el-table-column prop="deviceName" label="设备名称" />
                        <el-table-column prop="deviceTypeId" label="设备类型" show-overflow-tooltip>
                          <template #default="scope">
                            <span>{{equipmentState.equipmentTypeList.find(item =>item.id === scope.row.deviceTypeId)?.deviceType}}</span>
                          </template>
                        </el-table-column>
                        <el-table-column prop="deviceDesc" label="设备型号" />
                        <el-table-column prop="devicePower" label="设备功率">
                          <template #default="scope">
                            <span>{{scope.row.devicePower}}</span>
                          </template>
                        </el-table-column>
                        <el-table-column prop="deviceStatus" label="设备状态">
                            <template #default="scope">
                                <span>{{scope.row.deviceStatus == 1?'完好':'异常'}}</span>
                            </template>
                        </el-table-column>
                        <el-table-column prop="deviceUnit" label="计量单位" show-overflow-tooltip>
                          <template #default="scope">
                            <span>{{`${equipmentState.deviceUnitList.find(item =>item.id === scope.row.deviceUnit)?.name}`}}</span>
                          </template>
                        </el-table-column>
                        <el-table-column prop="specialDevice" label="是否特殊装备" show-overflow-tooltip>
                            <template #default="scope">
                                <span>{{`${equipmentState.specialDeviceList.find(item =>item.id === scope.row.specialDevice)?.name}`}}</span>
                            </template>
                        </el-table-column>
                        <el-table-column prop="safeProtect" label="安全防护"/>
                        <el-table-column prop="createTime" label="创建时间" show-overflow-tooltip></el-table-column>
                        <el-table-column prop="createByUserName" label="创建人" show-overflow-tooltip></el-table-column>
                        <el-table-column prop="updateTime" label="最后修改时间" show-overflow-tooltip></el-table-column>
                        <el-table-column prop="updateByUserName" label="最后修改人" show-overflow-tooltip></el-table-column>
                        <el-table-column label="操作" width="150">
                            <template #default="scope">
                                <el-button size="small" text type="primary" :icon="Edit" @click="openEquipmentDialog('修改', scope.row)">编辑</el-button>
                                <el-button size="small" text type="danger" :icon="Delete" @click="onDelEquipment(scope.row)">删除</el-button>
                            </template>
                        </el-table-column>
                    </el-table>
                    <div class="pageBtn">
                        <el-pagination @size-change="onHandleSizeChange" @current-change="onHandleCurrentChange" :pager-count="5" :page-sizes="[10, 20, 30]" v-model:current-page="equipmentState.searchQuery.pageIndex" background v-model:page-size="equipmentState.searchQuery.pageSize" layout="total, sizes, prev, pager, next, jumper" :total="equipmentState.total" class="page-position"> </el-pagination>
                    </div>
                </div>
            </div>
        </div>
        <equipment-dialog ref="equipmentDialogRef" @refresh="getEquipmentData" :equipmentTypeList="equipmentState.equipmentTypeList"></equipment-dialog>
    </div>
</template>

<script setup lang="ts">
import {defineAsyncComponent, onMounted, reactive, ref} from "vue";
import {equipmentApi} from "/@/api/basic/equipement";
import {ElMessage, ElMessageBox} from "element-plus";
import { Edit, View, Plus, Delete } from '@element-plus/icons-vue';

const EquipmentDialog = defineAsyncComponent(() => import('./components/equipmentDialog.vue'));

const equipmentDialogRef = ref();

const equipmentState = reactive<EquipmentStateType>({
    equipmentData: [],
    equipmentTypeList: [],
    searchQuery: {
        pageIndex: 1,
        pageSize: 10,
        deviceCode: '',
        deviceName: '',
        devicePower: '',
        specialDevice: null,
    },
    total: 0,
    specialDeviceList: [
        {id: 1, name: '是'},
        {id:2, name: '否'}
    ],
    deviceUnitList: [
        {id:1, name: '台'},
        {id:2, name: '个'},
        {id:3, name: '件'}
    ]
})

const getAllType = async ()=>{
  const res = await equipmentApi().getAllType();
  if(res.data.code === 100){
    equipmentState.equipmentTypeList = res.data.data
  }
}

const getEquipmentData = async () => {
    let res = await equipmentApi().getEquipmentByList(equipmentState.searchQuery);
    if(res.data.code === 100){
        equipmentState.equipmentData = res.data.data;
        equipmentState.total = res.data.total;
    }else{
        ElMessage({
            type: 'warning',
            message: res.data.msg
        });
    }
};

const openEquipmentDialog = (title: string, value: EquipmentType) => {
    equipmentDialogRef.value.showEquipmentDialog(title, value, equipmentState.specialDeviceList);
};

const onDelEquipment = (val: EquipmentType) => {
    ElMessageBox.confirm(`此操作将永久删除该设备：“${val.deviceName}”，是否继续?`, '提示', {
        confirmButtonText: '确认',
        cancelButtonText: '取消',
        type: 'warning'
    })
        .then(async () => {
            let res = await equipmentApi().deleteEquipmentById({ id: val.id });
            if (res.data.code === 100) {
                ElMessage({
                    type: 'success',
                    duration: 2000,
                    message: '删除成功'
                });
                await getEquipmentData();
            } else {
                ElMessage({
                    type: 'warning',
                    message: res.data.msg
                });
            }
        })
        .catch((error) => {
        });
}

const onHandleSizeChange = (val: number) => {
    equipmentState.searchQuery.pageSize = val;
    getEquipmentData();
};

const onHandleCurrentChange = (val: number) => {
    equipmentState.searchQuery.pageIndex = val;
    getEquipmentData();
};

const reset = () => {
    equipmentState.searchQuery = {
        pageIndex: 1,
        pageSize: 10,
        deviceCode: '',
        deviceName: '',
        devicePower: '',
        specialDevice: null,
    }
};

onMounted(() => {
    getEquipmentData()
    getAllType()
})

</script>

<style scoped lang="scss">
$homeNavLengh: 8;
.home-container {
    height: calc(100vh - 144px);
    box-sizing: border-box;
    overflow: hidden;
    .homeCard {
        width: 100%;
        padding: 20px;
        box-sizing: border-box;
        background: #fff;
        border-radius: 4px;

        .main-card {
            width: 100%;
            height: 100%;
            .cardTop {
                display: flex;
                align-items: center;
                justify-content: space-between;
                margin-bottom: 20px;
                .mainCardBtn {
                    margin: 0;
                }
            }
            .pageBtn {
                height: 60px;
                display: flex;
                align-items: center;
                justify-content: right;

                .demo-pagination-block + .demo-pagination-block {
                    margin-top: 10px;
                }
                .demo-pagination-block .demonstration {
                    margin-bottom: 16px;
                }
            }
        }
        &:last-of-type {
            height: calc(100% - 100px);
        }
    }
    .el-row {
        display: flex;
        align-items: center;
        margin-bottom: 20px;
        &:last-child {
            margin-bottom: 0;
        }
        .grid-content {
            align-items: center;
            min-height: 36px;
        }

        .topInfo {
            display: flex;
            align-items: center;
            font-size: 16px;
            font-weight: bold;

            & > div {
                white-space: nowrap;
                margin-right: 20px;
            }
        }
    }
}
.stepItem {
    width: 100%;
    display: flex;
    align-items: flex-start;
    margin-bottom: 30px;
    margin-left: 30px;
    padding-bottom: 30px;
    border-left: 2px solid #ccc;
    &:first-of-type {
        margin-top: 30px;
    }
    &:last-of-type {
        margin-bottom: 0;
        border-left: none;
    }
    .stepNum {
        width: 30px;
        height: 30px;
        border-radius: 15px;
        box-sizing: border-box;
        color: #333;
        border: 1px solid #999;
        line-height: 28px;
        text-align: center;
        margin-right: 10px;
        margin-left: -16px;
        margin-top: -30px;
    }
    .stepCard {
        width: 100%;
        margin-top: -30px;

        .box-card {
            width: 100%;
            &:deep(.el-card__header) {
                padding: 10px 15px;
            }
            .card-header {
                width: 100%;
                display: flex;
                justify-content: space-between;
                align-items: center;
                & > div:first-of-type {
                    margin-right: 80px;
                    font-size: 18px;
                    font-weight: bold;
                }
            }
        }
    }
    &:hover .card-header {
        color: #0098f5;
    }
    &:hover .stepNum {
        border: 2px solid #0098f5;
        color: #0098f5;
    }
}

:deep(.el-date-editor) {
    width: 100%;
}
.el-select {
    width: 100%;
}
:deep(.el-textarea.is-disabled .el-textarea__inner) {
    background-color: var(--el-card-bg-color);
    color: var(--el-input-text-color, var(--el-text-color-regular));
}
:deep(.el-input.is-disabled .el-input__inner) {
    color: var(--el-input-text-color, var(--el-text-color-regular));
}
:deep(.el-input.is-disabled .el-input__wrapper) {
    background-color: var(--el-card-bg-color);
}
</style>
